Pypi statistics

- Ignoring package 'lessormore': Error while getting data for package 'lessormore': Expecting value: line 2 column 1 (char 1).
- Ignoring package 'pypimonitor': Error while getting data for package 'pypimonitor': Expecting value: line 2 column 1 (char 1).
- Ignoring package 'squelette': Error while getting data for package 'squelette': Expecting value: line 2 column 1 (char 1).

| Home | Version | Monthly | Weekly | Daily | Doc | CI
| argdispatch |  |  |  |  |  |
| Cahier |  |  |  |  |  |
| chval |  |  |  |  |  |
| Devoir |  |  |  |  |  |
| DummyPdf |  |  |  |  |  |
| Evariste |  |  |  |  |  |
| fullcoverage |  |  |  |  |  |
| Jouets |  |  |  |  |  |
| mklog |  |  |  |  |  |
| PaperSize |  |  |  |  |  |
| patacrep |  |  |  |  |  |
| PdfAutoNup |  |  |  |  |  |
| PdfImpose |  |  |  |  |  |
| Scal |  |  |  |  |  |
| sphinxcontrib-packages |  |  |  |  |  |
| sphinxcontrib-proof |  |  |  |  |  |
| srsync |  |  |  |  |  |